# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/assistant/assistant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/assistant/assistant.proto',
  package='sensory.api.v1.assistant',
  syntax='proto3',
  serialized_options=b'\n ai.sensorycloud.api.v1.assistantB\032SensoryApiV1AssistantProtoP\001Z>gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/assistant',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cv1/assistant/assistant.proto\x12\x18sensory.api.v1.assistant\x1a\x17validate/validate.proto\"\x93\x02\n\x17\x41ssistantMessageRequest\x12\x42\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x30.sensory.api.v1.assistant.AssistantMessageConfigH\x00\x12=\n\x07message\x18\x02 \x01(\x0b\x32*.sensory.api.v1.assistant.AssistantMessageH\x00\x12\\\n\x14postProcessingAction\x18\n \x01(\x0b\x32>.sensory.api.v1.assistant.AssistantPostProcessingActionRequestB\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"V\n\x10\x41ssistantMessage\x12\x1a\n\x04text\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x0fH\x00\x12\x16\n\x0c\x61udioContent\x18\x02 \x01(\x0cH\x00\x42\x0e\n\x07message\x12\x03\xf8\x42\x01\"*\n\x06Intent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"\x9b\x02\n\x18\x41ssistantMessageResponse\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x14\n\x0c\x61udioContent\x18\x02 \x01(\x0c\x12\x30\n\x06intent\x18\x03 \x01(\x0b\x32 .sensory.api.v1.assistant.Intent\x12\x31\n\x07intents\x18\x04 \x03(\x0b\x32 .sensory.api.v1.assistant.Intent\x12\x17\n\x0fisAudioComplete\x18\x05 \x01(\x08\x12]\n\x14postProcessingAction\x18\n \x01(\x0b\x32?.sensory.api.v1.assistant.AssistantPostProcessingActionResponse\"\x8d\x01\n\x16\x41ssistantMessageConfig\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1b\n\x08\x64\x65viceId\x18\x03 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x04 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1c\n\x14includeAudioResponse\x18\x05 \x01(\x08\"\x8b\x01\n$AssistantPostProcessingActionRequest\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x37.sensory.api.v1.assistant.AssistantPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\x8c\x01\n%AssistantPostProcessingActionResponse\x12\x10\n\x08\x61\x63tionId\x18\x01 \x01(\t\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x37.sensory.api.v1.assistant.AssistantPostProcessingActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01*7\n\x1d\x41ssistantPostProcessingAction\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05\x46INAL\x10\x01\x32\x91\x01\n\x10\x41ssistantService\x12}\n\x0eProcessMessage\x12\x31.sensory.api.v1.assistant.AssistantMessageRequest\x1a\x32.sensory.api.v1.assistant.AssistantMessageResponse\"\x00(\x01\x30\x01\x42\x80\x01\n ai.sensorycloud.api.v1.assistantB\x1aSensoryApiV1AssistantProtoP\x01Z>gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/assistantb\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,])

_ASSISTANTPOSTPROCESSINGACTION = _descriptor.EnumDescriptor(
  name='AssistantPostProcessingAction',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SET', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1208,
  serialized_end=1263,
)
_sym_db.RegisterEnumDescriptor(_ASSISTANTPOSTPROCESSINGACTION)

AssistantPostProcessingAction = enum_type_wrapper.EnumTypeWrapper(_ASSISTANTPOSTPROCESSINGACTION)
NOT_SET = 0
FINAL = 1



_ASSISTANTMESSAGEREQUEST = _descriptor.Descriptor(
  name='AssistantMessageRequest',
  full_name='sensory.api.v1.assistant.AssistantMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.assistant.AssistantMessageRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='sensory.api.v1.assistant.AssistantMessageRequest.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.assistant.AssistantMessageRequest.postProcessingAction', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.assistant.AssistantMessageRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=84,
  serialized_end=359,
)


_ASSISTANTMESSAGE = _descriptor.Descriptor(
  name='AssistantMessage',
  full_name='sensory.api.v1.assistant.AssistantMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='sensory.api.v1.assistant.AssistantMessage.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\017', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.assistant.AssistantMessage.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='message', full_name='sensory.api.v1.assistant.AssistantMessage.message',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=361,
  serialized_end=447,
)


_INTENT = _descriptor.Descriptor(
  name='Intent',
  full_name='sensory.api.v1.assistant.Intent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.assistant.Intent.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='sensory.api.v1.assistant.Intent.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=491,
)


_ASSISTANTMESSAGERESPONSE = _descriptor.Descriptor(
  name='AssistantMessageResponse',
  full_name='sensory.api.v1.assistant.AssistantMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='sensory.api.v1.assistant.AssistantMessageResponse.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audioContent', full_name='sensory.api.v1.assistant.AssistantMessageResponse.audioContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intent', full_name='sensory.api.v1.assistant.AssistantMessageResponse.intent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intents', full_name='sensory.api.v1.assistant.AssistantMessageResponse.intents', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAudioComplete', full_name='sensory.api.v1.assistant.AssistantMessageResponse.isAudioComplete', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postProcessingAction', full_name='sensory.api.v1.assistant.AssistantMessageResponse.postProcessingAction', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=777,
)


_ASSISTANTMESSAGECONFIG = _descriptor.Descriptor(
  name='AssistantMessageConfig',
  full_name='sensory.api.v1.assistant.AssistantMessageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.assistant.AssistantMessageConfig.userId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.assistant.AssistantMessageConfig.deviceId', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.assistant.AssistantMessageConfig.modelName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeAudioResponse', full_name='sensory.api.v1.assistant.AssistantMessageConfig.includeAudioResponse', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=921,
)


_ASSISTANTPOSTPROCESSINGACTIONREQUEST = _descriptor.Descriptor(
  name='AssistantPostProcessingActionRequest',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionRequest.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1063,
)


_ASSISTANTPOSTPROCESSINGACTIONRESPONSE = _descriptor.Descriptor(
  name='AssistantPostProcessingActionResponse',
  full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actionId', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse.actionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='sensory.api.v1.assistant.AssistantPostProcessingActionResponse.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1206,
)

_ASSISTANTMESSAGEREQUEST.fields_by_name['config'].message_type = _ASSISTANTMESSAGECONFIG
_ASSISTANTMESSAGEREQUEST.fields_by_name['message'].message_type = _ASSISTANTMESSAGE
_ASSISTANTMESSAGEREQUEST.fields_by_name['postProcessingAction'].message_type = _ASSISTANTPOSTPROCESSINGACTIONREQUEST
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _ASSISTANTMESSAGEREQUEST.fields_by_name['config'])
_ASSISTANTMESSAGEREQUEST.fields_by_name['config'].containing_oneof = _ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _ASSISTANTMESSAGEREQUEST.fields_by_name['message'])
_ASSISTANTMESSAGEREQUEST.fields_by_name['message'].containing_oneof = _ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']
_ASSISTANTMESSAGE.oneofs_by_name['message'].fields.append(
  _ASSISTANTMESSAGE.fields_by_name['text'])
_ASSISTANTMESSAGE.fields_by_name['text'].containing_oneof = _ASSISTANTMESSAGE.oneofs_by_name['message']
_ASSISTANTMESSAGE.oneofs_by_name['message'].fields.append(
  _ASSISTANTMESSAGE.fields_by_name['audioContent'])
_ASSISTANTMESSAGE.fields_by_name['audioContent'].containing_oneof = _ASSISTANTMESSAGE.oneofs_by_name['message']
_ASSISTANTMESSAGERESPONSE.fields_by_name['intent'].message_type = _INTENT
_ASSISTANTMESSAGERESPONSE.fields_by_name['intents'].message_type = _INTENT
_ASSISTANTMESSAGERESPONSE.fields_by_name['postProcessingAction'].message_type = _ASSISTANTPOSTPROCESSINGACTIONRESPONSE
_ASSISTANTPOSTPROCESSINGACTIONREQUEST.fields_by_name['action'].enum_type = _ASSISTANTPOSTPROCESSINGACTION
_ASSISTANTPOSTPROCESSINGACTIONRESPONSE.fields_by_name['action'].enum_type = _ASSISTANTPOSTPROCESSINGACTION
DESCRIPTOR.message_types_by_name['AssistantMessageRequest'] = _ASSISTANTMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['AssistantMessage'] = _ASSISTANTMESSAGE
DESCRIPTOR.message_types_by_name['Intent'] = _INTENT
DESCRIPTOR.message_types_by_name['AssistantMessageResponse'] = _ASSISTANTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['AssistantMessageConfig'] = _ASSISTANTMESSAGECONFIG
DESCRIPTOR.message_types_by_name['AssistantPostProcessingActionRequest'] = _ASSISTANTPOSTPROCESSINGACTIONREQUEST
DESCRIPTOR.message_types_by_name['AssistantPostProcessingActionResponse'] = _ASSISTANTPOSTPROCESSINGACTIONRESPONSE
DESCRIPTOR.enum_types_by_name['AssistantPostProcessingAction'] = _ASSISTANTPOSTPROCESSINGACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AssistantMessageRequest = _reflection.GeneratedProtocolMessageType('AssistantMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGEREQUEST,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageRequest)
  })
_sym_db.RegisterMessage(AssistantMessageRequest)

AssistantMessage = _reflection.GeneratedProtocolMessageType('AssistantMessage', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessage)
  })
_sym_db.RegisterMessage(AssistantMessage)

Intent = _reflection.GeneratedProtocolMessageType('Intent', (_message.Message,), {
  'DESCRIPTOR' : _INTENT,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.Intent)
  })
_sym_db.RegisterMessage(Intent)

AssistantMessageResponse = _reflection.GeneratedProtocolMessageType('AssistantMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGERESPONSE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageResponse)
  })
_sym_db.RegisterMessage(AssistantMessageResponse)

AssistantMessageConfig = _reflection.GeneratedProtocolMessageType('AssistantMessageConfig', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTMESSAGECONFIG,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantMessageConfig)
  })
_sym_db.RegisterMessage(AssistantMessageConfig)

AssistantPostProcessingActionRequest = _reflection.GeneratedProtocolMessageType('AssistantPostProcessingActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTPOSTPROCESSINGACTIONREQUEST,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantPostProcessingActionRequest)
  })
_sym_db.RegisterMessage(AssistantPostProcessingActionRequest)

AssistantPostProcessingActionResponse = _reflection.GeneratedProtocolMessageType('AssistantPostProcessingActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASSISTANTPOSTPROCESSINGACTIONRESPONSE,
  '__module__' : 'v1.assistant.assistant_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.assistant.AssistantPostProcessingActionResponse)
  })
_sym_db.RegisterMessage(AssistantPostProcessingActionResponse)


DESCRIPTOR._options = None
_ASSISTANTMESSAGEREQUEST.oneofs_by_name['streamingRequest']._options = None
_ASSISTANTMESSAGE.oneofs_by_name['message']._options = None
_ASSISTANTMESSAGE.fields_by_name['text']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['userId']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['deviceId']._options = None
_ASSISTANTMESSAGECONFIG.fields_by_name['modelName']._options = None
_ASSISTANTPOSTPROCESSINGACTIONREQUEST.fields_by_name['action']._options = None
_ASSISTANTPOSTPROCESSINGACTIONRESPONSE.fields_by_name['action']._options = None

_ASSISTANTSERVICE = _descriptor.ServiceDescriptor(
  name='AssistantService',
  full_name='sensory.api.v1.assistant.AssistantService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1266,
  serialized_end=1411,
  methods=[
  _descriptor.MethodDescriptor(
    name='ProcessMessage',
    full_name='sensory.api.v1.assistant.AssistantService.ProcessMessage',
    index=0,
    containing_service=None,
    input_type=_ASSISTANTMESSAGEREQUEST,
    output_type=_ASSISTANTMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASSISTANTSERVICE)

DESCRIPTOR.services_by_name['AssistantService'] = _ASSISTANTSERVICE

# @@protoc_insertion_point(module_scope)
