# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/video/video.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/video/video.proto',
  package='sensory.api.v1.video',
  syntax='proto3',
  serialized_options=b'\n\034ai.sensorycloud.api.v1.videoB\026SensoryApiV1VideoProtoP\001Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/video',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14v1/video/video.proto\x12\x14sensory.api.v1.video\x1a\x17validate/validate.proto\x1a\x13\x63ommon/common.proto\"\xde\x01\n\nVideoModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cisEnrollable\x18\x02 \x01(\x08\x12\x30\n\tmodelType\x18\x03 \x01(\x0e\x32\x1d.sensory.api.common.ModelType\x12\x13\n\x0b\x66ixedObject\x18\x04 \x01(\t\x12\x10\n\x08versions\x18\x05 \x03(\t\x12\x36\n\ntechnology\x18\x06 \x01(\x0e\x32\".sensory.api.common.TechnologyType\x12\x1b\n\x13isLivenessSupported\x18\x07 \x01(\x08\"\x12\n\x10GetModelsRequest\"E\n\x11GetModelsResponse\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .sensory.api.v1.video.VideoModel\"\x8a\x01\n\x17\x43reateEnrollmentRequest\x12>\n\x06\x63onfig\x18\x01 \x01(\x0b\x32,.sensory.api.v1.video.CreateEnrollmentConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x82\x01\n\x13\x41uthenticateRequest\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.sensory.api.v1.video.AuthenticateConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x90\x01\n\x1aValidateRecognitionRequest\x12\x41\n\x06\x63onfig\x18\x01 \x01(\x0b\x32/.sensory.api.v1.video.ValidateRecognitionConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\xd0\x01\n\x18\x43reateEnrollmentResponse\x12\x17\n\x0fpercentComplete\x18\x01 \x01(\x03\x12\x0f\n\x07isAlive\x18\x02 \x01(\x08\x12\x14\n\x0c\x65nrollmentId\x18\x03 \x01(\t\x12\x11\n\tmodelName\x18\x04 \x01(\t\x12\x14\n\x0cmodelVersion\x18\x05 \x01(\t\x12\r\n\x05score\x18\x06 \x01(\x02\x12<\n\x0f\x65nrollmentToken\x18\x07 \x01(\x0b\x32#.sensory.api.common.EnrollmentToken\"\x9f\x01\n\x14\x41uthenticateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x0f\n\x07isAlive\x18\x03 \x01(\x08\x12\x30\n\x05token\x18\x04 \x01(\x0b\x32!.sensory.api.common.TokenResponse\x12\x0e\n\x06userId\x18\x05 \x01(\t\x12\x14\n\x0c\x65nrollmentId\x18\x06 \x01(\t\"=\n\x1bLivenessRecognitionResponse\x12\x0f\n\x07isAlive\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x02\"\xae\x03\n\x16\x43reateEnrollmentConfig\x12\x19\n\x06userId\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1b\n\x08\x64\x65viceId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1d\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\x12\x19\n\x11isLivenessEnabled\x18\x05 \x01(\x08\x12O\n\x11livenessThreshold\x18\x06 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x0b\x63ompression\x18\x07 \x01(\x0b\x32,.sensory.api.common.CompressionConfiguration\x12\x1c\n\x0breferenceId\x18\x08 \x01(\tB\x07\xfa\x42\x04r\x02\x18\x7f\x12!\n\x19numLivenessFramesRequired\x18\t \x01(\x05\x12.\n&disableServerEnrollmentTemplateStorage\x18\n \x01(\x08\"\xc2\x02\n\x12\x41uthenticateConfig\x12 \n\x0c\x65nrollmentId\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x1b\n\x11\x65nrollmentGroupId\x18\x02 \x01(\tH\x00\x12\x19\n\x11isLivenessEnabled\x18\x03 \x01(\x08\x12O\n\x11livenessThreshold\x18\x04 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x0b\x63ompression\x18\x05 \x01(\x0b\x32,.sensory.api.common.CompressionConfiguration\x12\x16\n\x0e\x64oIncludeToken\x18\x06 \x01(\x08\x12\x17\n\x0f\x65nrollmentToken\x18\x07 \x01(\x0c\x42\r\n\x06\x61uthId\x12\x03\xf8\x42\x01\"\x9e\x01\n\x19ValidateRecognitionConfig\x12\x1d\n\tmodelName\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12G\n\tthreshold\x18\x03 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01*B\n\x14RecognitionThreshold\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x0b\n\x07HIGHEST\x10\x03\x32m\n\x0bVideoModels\x12^\n\tGetModels\x12&.sensory.api.v1.video.GetModelsRequest\x1a\'.sensory.api.v1.video.GetModelsResponse\"\x00\x32\xf7\x01\n\x0fVideoBiometrics\x12w\n\x10\x43reateEnrollment\x12-.sensory.api.v1.video.CreateEnrollmentRequest\x1a..sensory.api.v1.video.CreateEnrollmentResponse\"\x00(\x01\x30\x01\x12k\n\x0c\x41uthenticate\x12).sensory.api.v1.video.AuthenticateRequest\x1a*.sensory.api.v1.video.AuthenticateResponse\"\x00(\x01\x30\x01\x32\x91\x01\n\x10VideoRecognition\x12}\n\x10ValidateLiveness\x12\x30.sensory.api.v1.video.ValidateRecognitionRequest\x1a\x31.sensory.api.v1.video.LivenessRecognitionResponse\"\x00(\x01\x30\x01\x42t\n\x1c\x61i.sensorycloud.api.v1.videoB\x16SensoryApiV1VideoProtoP\x01Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/videob\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,common_dot_common__pb2.DESCRIPTOR,])

_RECOGNITIONTHRESHOLD = _descriptor.EnumDescriptor(
  name='RecognitionThreshold',
  full_name='sensory.api.v1.video.RecognitionThreshold',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2184,
  serialized_end=2250,
)
_sym_db.RegisterEnumDescriptor(_RECOGNITIONTHRESHOLD)

RecognitionThreshold = enum_type_wrapper.EnumTypeWrapper(_RECOGNITIONTHRESHOLD)
LOW = 0
MEDIUM = 1
HIGH = 2
HIGHEST = 3



_VIDEOMODEL = _descriptor.Descriptor(
  name='VideoModel',
  full_name='sensory.api.v1.video.VideoModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.video.VideoModel.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isEnrollable', full_name='sensory.api.v1.video.VideoModel.isEnrollable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelType', full_name='sensory.api.v1.video.VideoModel.modelType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixedObject', full_name='sensory.api.v1.video.VideoModel.fixedObject', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='sensory.api.v1.video.VideoModel.versions', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='sensory.api.v1.video.VideoModel.technology', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessSupported', full_name='sensory.api.v1.video.VideoModel.isLivenessSupported', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=315,
)


_GETMODELSREQUEST = _descriptor.Descriptor(
  name='GetModelsRequest',
  full_name='sensory.api.v1.video.GetModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=335,
)


_GETMODELSRESPONSE = _descriptor.Descriptor(
  name='GetModelsResponse',
  full_name='sensory.api.v1.video.GetModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='sensory.api.v1.video.GetModelsResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=406,
)


_CREATEENROLLMENTREQUEST = _descriptor.Descriptor(
  name='CreateEnrollmentRequest',
  full_name='sensory.api.v1.video.CreateEnrollmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.CreateEnrollmentRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.CreateEnrollmentRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.CreateEnrollmentRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=409,
  serialized_end=547,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='sensory.api.v1.video.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.AuthenticateRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.AuthenticateRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.AuthenticateRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=550,
  serialized_end=680,
)


_VALIDATERECOGNITIONREQUEST = _descriptor.Descriptor(
  name='ValidateRecognitionRequest',
  full_name='sensory.api.v1.video.ValidateRecognitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.ValidateRecognitionRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.ValidateRecognitionRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.ValidateRecognitionRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=683,
  serialized_end=827,
)


_CREATEENROLLMENTRESPONSE = _descriptor.Descriptor(
  name='CreateEnrollmentResponse',
  full_name='sensory.api.v1.video.CreateEnrollmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentComplete', full_name='sensory.api.v1.video.CreateEnrollmentResponse.percentComplete', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.CreateEnrollmentResponse.isAlive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.CreateEnrollmentResponse.enrollmentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.CreateEnrollmentResponse.modelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelVersion', full_name='sensory.api.v1.video.CreateEnrollmentResponse.modelVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.CreateEnrollmentResponse.score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.video.CreateEnrollmentResponse.enrollmentToken', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=1038,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='sensory.api.v1.video.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='sensory.api.v1.video.AuthenticateResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.AuthenticateResponse.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.AuthenticateResponse.isAlive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='sensory.api.v1.video.AuthenticateResponse.token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.AuthenticateResponse.userId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.AuthenticateResponse.enrollmentId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1200,
)


_LIVENESSRECOGNITIONRESPONSE = _descriptor.Descriptor(
  name='LivenessRecognitionResponse',
  full_name='sensory.api.v1.video.LivenessRecognitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.LivenessRecognitionResponse.isAlive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.LivenessRecognitionResponse.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1263,
)


_CREATEENROLLMENTCONFIG = _descriptor.Descriptor(
  name='CreateEnrollmentConfig',
  full_name='sensory.api.v1.video.CreateEnrollmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.userId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.deviceId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.CreateEnrollmentConfig.modelName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.video.CreateEnrollmentConfig.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.video.CreateEnrollmentConfig.isLivenessEnabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessThreshold', full_name='sensory.api.v1.video.CreateEnrollmentConfig.livenessThreshold', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='sensory.api.v1.video.CreateEnrollmentConfig.compression', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenceId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.referenceId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numLivenessFramesRequired', full_name='sensory.api.v1.video.CreateEnrollmentConfig.numLivenessFramesRequired', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disableServerEnrollmentTemplateStorage', full_name='sensory.api.v1.video.CreateEnrollmentConfig.disableServerEnrollmentTemplateStorage', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1696,
)


_AUTHENTICATECONFIG = _descriptor.Descriptor(
  name='AuthenticateConfig',
  full_name='sensory.api.v1.video.AuthenticateConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentGroupId', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.video.AuthenticateConfig.isLivenessEnabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessThreshold', full_name='sensory.api.v1.video.AuthenticateConfig.livenessThreshold', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='sensory.api.v1.video.AuthenticateConfig.compression', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doIncludeToken', full_name='sensory.api.v1.video.AuthenticateConfig.doIncludeToken', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentToken', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authId', full_name='sensory.api.v1.video.AuthenticateConfig.authId',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1699,
  serialized_end=2021,
)


_VALIDATERECOGNITIONCONFIG = _descriptor.Descriptor(
  name='ValidateRecognitionConfig',
  full_name='sensory.api.v1.video.ValidateRecognitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.ValidateRecognitionConfig.modelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.ValidateRecognitionConfig.userId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='sensory.api.v1.video.ValidateRecognitionConfig.threshold', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2182,
)

_VIDEOMODEL.fields_by_name['modelType'].enum_type = common_dot_common__pb2._MODELTYPE
_VIDEOMODEL.fields_by_name['technology'].enum_type = common_dot_common__pb2._TECHNOLOGYTYPE
_GETMODELSRESPONSE.fields_by_name['models'].message_type = _VIDEOMODEL
_CREATEENROLLMENTREQUEST.fields_by_name['config'].message_type = _CREATEENROLLMENTCONFIG
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['config'])
_CREATEENROLLMENTREQUEST.fields_by_name['config'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['imageContent'])
_CREATEENROLLMENTREQUEST.fields_by_name['imageContent'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.fields_by_name['config'].message_type = _AUTHENTICATECONFIG
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['config'])
_AUTHENTICATEREQUEST.fields_by_name['config'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['imageContent'])
_AUTHENTICATEREQUEST.fields_by_name['imageContent'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_VALIDATERECOGNITIONREQUEST.fields_by_name['config'].message_type = _VALIDATERECOGNITIONCONFIG
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATERECOGNITIONREQUEST.fields_by_name['config'])
_VALIDATERECOGNITIONREQUEST.fields_by_name['config'].containing_oneof = _VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATERECOGNITIONREQUEST.fields_by_name['imageContent'])
_VALIDATERECOGNITIONREQUEST.fields_by_name['imageContent'].containing_oneof = _VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLMENTRESPONSE.fields_by_name['enrollmentToken'].message_type = common_dot_common__pb2._ENROLLMENTTOKEN
_AUTHENTICATERESPONSE.fields_by_name['token'].message_type = common_dot_common__pb2._TOKENRESPONSE
_CREATEENROLLMENTCONFIG.fields_by_name['livenessThreshold'].enum_type = _RECOGNITIONTHRESHOLD
_CREATEENROLLMENTCONFIG.fields_by_name['compression'].message_type = common_dot_common__pb2._COMPRESSIONCONFIGURATION
_AUTHENTICATECONFIG.fields_by_name['livenessThreshold'].enum_type = _RECOGNITIONTHRESHOLD
_AUTHENTICATECONFIG.fields_by_name['compression'].message_type = common_dot_common__pb2._COMPRESSIONCONFIGURATION
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_VALIDATERECOGNITIONCONFIG.fields_by_name['threshold'].enum_type = _RECOGNITIONTHRESHOLD
DESCRIPTOR.message_types_by_name['VideoModel'] = _VIDEOMODEL
DESCRIPTOR.message_types_by_name['GetModelsRequest'] = _GETMODELSREQUEST
DESCRIPTOR.message_types_by_name['GetModelsResponse'] = _GETMODELSRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentRequest'] = _CREATEENROLLMENTREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['ValidateRecognitionRequest'] = _VALIDATERECOGNITIONREQUEST
DESCRIPTOR.message_types_by_name['CreateEnrollmentResponse'] = _CREATEENROLLMENTRESPONSE
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['LivenessRecognitionResponse'] = _LIVENESSRECOGNITIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentConfig'] = _CREATEENROLLMENTCONFIG
DESCRIPTOR.message_types_by_name['AuthenticateConfig'] = _AUTHENTICATECONFIG
DESCRIPTOR.message_types_by_name['ValidateRecognitionConfig'] = _VALIDATERECOGNITIONCONFIG
DESCRIPTOR.enum_types_by_name['RecognitionThreshold'] = _RECOGNITIONTHRESHOLD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VideoModel = _reflection.GeneratedProtocolMessageType('VideoModel', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMODEL,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.VideoModel)
  })
_sym_db.RegisterMessage(VideoModel)

GetModelsRequest = _reflection.GeneratedProtocolMessageType('GetModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.GetModelsRequest)
  })
_sym_db.RegisterMessage(GetModelsRequest)

GetModelsResponse = _reflection.GeneratedProtocolMessageType('GetModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.GetModelsResponse)
  })
_sym_db.RegisterMessage(GetModelsResponse)

CreateEnrollmentRequest = _reflection.GeneratedProtocolMessageType('CreateEnrollmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentRequest)
  })
_sym_db.RegisterMessage(CreateEnrollmentRequest)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

ValidateRecognitionRequest = _reflection.GeneratedProtocolMessageType('ValidateRecognitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATERECOGNITIONREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.ValidateRecognitionRequest)
  })
_sym_db.RegisterMessage(ValidateRecognitionRequest)

CreateEnrollmentResponse = _reflection.GeneratedProtocolMessageType('CreateEnrollmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentResponse)
  })
_sym_db.RegisterMessage(CreateEnrollmentResponse)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

LivenessRecognitionResponse = _reflection.GeneratedProtocolMessageType('LivenessRecognitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LIVENESSRECOGNITIONRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.LivenessRecognitionResponse)
  })
_sym_db.RegisterMessage(LivenessRecognitionResponse)

CreateEnrollmentConfig = _reflection.GeneratedProtocolMessageType('CreateEnrollmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTCONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentConfig)
  })
_sym_db.RegisterMessage(CreateEnrollmentConfig)

AuthenticateConfig = _reflection.GeneratedProtocolMessageType('AuthenticateConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATECONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateConfig)
  })
_sym_db.RegisterMessage(AuthenticateConfig)

ValidateRecognitionConfig = _reflection.GeneratedProtocolMessageType('ValidateRecognitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATERECOGNITIONCONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.ValidateRecognitionConfig)
  })
_sym_db.RegisterMessage(ValidateRecognitionConfig)


DESCRIPTOR._options = None
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']._options = None
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['userId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['deviceId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['modelName']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['description']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['livenessThreshold']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['referenceId']._options = None
_AUTHENTICATECONFIG.oneofs_by_name['authId']._options = None
_AUTHENTICATECONFIG.fields_by_name['enrollmentId']._options = None
_AUTHENTICATECONFIG.fields_by_name['livenessThreshold']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['modelName']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['userId']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['threshold']._options = None

_VIDEOMODELS = _descriptor.ServiceDescriptor(
  name='VideoModels',
  full_name='sensory.api.v1.video.VideoModels',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2252,
  serialized_end=2361,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetModels',
    full_name='sensory.api.v1.video.VideoModels.GetModels',
    index=0,
    containing_service=None,
    input_type=_GETMODELSREQUEST,
    output_type=_GETMODELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEOMODELS)

DESCRIPTOR.services_by_name['VideoModels'] = _VIDEOMODELS


_VIDEOBIOMETRICS = _descriptor.ServiceDescriptor(
  name='VideoBiometrics',
  full_name='sensory.api.v1.video.VideoBiometrics',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2364,
  serialized_end=2611,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateEnrollment',
    full_name='sensory.api.v1.video.VideoBiometrics.CreateEnrollment',
    index=0,
    containing_service=None,
    input_type=_CREATEENROLLMENTREQUEST,
    output_type=_CREATEENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='sensory.api.v1.video.VideoBiometrics.Authenticate',
    index=1,
    containing_service=None,
    input_type=_AUTHENTICATEREQUEST,
    output_type=_AUTHENTICATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEOBIOMETRICS)

DESCRIPTOR.services_by_name['VideoBiometrics'] = _VIDEOBIOMETRICS


_VIDEORECOGNITION = _descriptor.ServiceDescriptor(
  name='VideoRecognition',
  full_name='sensory.api.v1.video.VideoRecognition',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2614,
  serialized_end=2759,
  methods=[
  _descriptor.MethodDescriptor(
    name='ValidateLiveness',
    full_name='sensory.api.v1.video.VideoRecognition.ValidateLiveness',
    index=0,
    containing_service=None,
    input_type=_VALIDATERECOGNITIONREQUEST,
    output_type=_LIVENESSRECOGNITIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEORECOGNITION)

DESCRIPTOR.services_by_name['VideoRecognition'] = _VIDEORECOGNITION

# @@protoc_insertion_point(module_scope)
