# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health/health.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='health/health.proto',
  package='sensory.api.health',
  syntax='proto3',
  serialized_options=b'\n\032ai.sensorycloud.api.healthB\025SensoryApiHealthProtoP\001Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/health',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13health/health.proto\x12\x12sensory.api.health\x1a\x13\x63ommon/common.proto\"\x0f\n\rHealthRequest2k\n\rHealthService\x12Z\n\tGetHealth\x12!.sensory.api.health.HealthRequest\x1a(.sensory.api.common.ServerHealthResponse\"\x00\x42o\n\x1a\x61i.sensorycloud.api.healthB\x15SensoryApiHealthProtoP\x01Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/healthb\x06proto3'
  ,
  dependencies=[common_dot_common__pb2.DESCRIPTOR,])




_HEALTHREQUEST = _descriptor.Descriptor(
  name='HealthRequest',
  full_name='sensory.api.health.HealthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=79,
)

DESCRIPTOR.message_types_by_name['HealthRequest'] = _HEALTHREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthRequest = _reflection.GeneratedProtocolMessageType('HealthRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHREQUEST,
  '__module__' : 'health.health_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.health.HealthRequest)
  })
_sym_db.RegisterMessage(HealthRequest)


DESCRIPTOR._options = None

_HEALTHSERVICE = _descriptor.ServiceDescriptor(
  name='HealthService',
  full_name='sensory.api.health.HealthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=81,
  serialized_end=188,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealth',
    full_name='sensory.api.health.HealthService.GetHealth',
    index=0,
    containing_service=None,
    input_type=_HEALTHREQUEST,
    output_type=common_dot_common__pb2._SERVERHEALTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHSERVICE)

DESCRIPTOR.services_by_name['HealthService'] = _HEALTHSERVICE

# @@protoc_insertion_point(module_scope)
