# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/management/enrollment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/management/enrollment.proto',
  package='sensory.api.v1.management',
  syntax='proto3',
  serialized_options=b'\n!ai.sensorycloud.api.v1.managementB%SensoryApiV1ManagementEnrollmentProtoP\001Z?gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/management',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ev1/management/enrollment.proto\x12\x19sensory.api.v1.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a\x13\x63ommon/common.proto\"2\n\x15GetEnrollmentsRequest\x12\x19\n\x06userId\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\"x\n\x16GetEnrollmentsResponse\x12\x42\n\x0b\x65nrollments\x18\x01 \x03(\x0b\x32-.sensory.api.v1.management.EnrollmentResponse\x12\x1a\n\x12isRequestorTrusted\x18\x02 \x01(\x08\"\xb9\x03\n\x12\x45nrollmentResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\tcreatedAt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tupdatedAt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tmodelName\x18\x05 \x01(\t\x12\x30\n\tmodelType\x18\x06 \x01(\x0e\x32\x1d.sensory.api.common.ModelType\x12\x14\n\x0cmodelVersion\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65viceId\x18\x08 \x01(\t\x12\x0e\n\x06userId\x18\t \x01(\t\x12\x41\n\x0b\x63ompression\x18\n \x01(\x0b\x32,.sensory.api.common.CompressionConfiguration\x12\x12\n\ndeviceName\x18\x0b \x01(\t\x12\x1d\n\x15\x64idEnrollWithLiveness\x18\x0c \x01(\x08\x12\x13\n\x0breferenceId\x18\r \x01(\t\x12\x1c\n\x14\x64idEnrollAsBiometric\x18\x0e \x01(\x08\"k\n\x1bGetEnrollmentGroupsResponse\x12L\n\x10\x65nrollmentGroups\x18\x01 \x03(\x0b\x32\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\xd5\x02\n\x17\x45nrollmentGroupResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\tcreatedAt\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tupdatedAt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x11\n\tmodelName\x18\x06 \x01(\t\x12\x30\n\tmodelType\x18\x07 \x01(\x0e\x32\x1d.sensory.api.common.ModelType\x12\x14\n\x0cmodelVersion\x18\x08 \x01(\t\x12\x0e\n\x06userId\x18\t \x01(\t\x12\x42\n\x0b\x65nrollments\x18\n \x03(\x0b\x32-.sensory.api.v1.management.EnrollmentResponse\"\xbf\x01\n\x1c\x43reateEnrollmentGroupRequest\x12\x15\n\x02id\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x18\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1d\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\x12\x1d\n\tmodelName\x18\x04 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x19\n\x06userId\x18\x05 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x15\n\renrollmentIds\x18\x06 \x03(\t\"Q\n\x1c\x41ppendEnrollmentGroupRequest\x12\x1a\n\x07groupId\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x15\n\renrollmentIds\x18\x02 \x03(\t\"/\n\x17\x44\x65leteEnrollmentRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\"5\n\x1c\x44\x65leteEnrollmentGroupRequest\x12\x15\n\x02id\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\"N\n\x17UpdateEnrollmentRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12\x1d\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\"N\n\x1cUpdateEnrollmentGroupRequest\x12\x15\n\x02id\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x17\n\x04name\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\"W\n\x18RemoveEnrollmentsRequest\x12\x1a\n\x07groupId\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1f\n\renrollmentIds\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x32\xb0\t\n\x11\x45nrollmentService\x12w\n\x0eGetEnrollments\x12\x30.sensory.api.v1.management.GetEnrollmentsRequest\x1a\x31.sensory.api.v1.management.GetEnrollmentsResponse\"\x00\x12\x81\x01\n\x13GetEnrollmentGroups\x12\x30.sensory.api.v1.management.GetEnrollmentsRequest\x1a\x36.sensory.api.v1.management.GetEnrollmentGroupsResponse\"\x00\x12\x86\x01\n\x15\x43reateEnrollmentGroup\x12\x37.sensory.api.v1.management.CreateEnrollmentGroupRequest\x1a\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\x00\x12\x86\x01\n\x15\x41ppendEnrollmentGroup\x12\x37.sensory.api.v1.management.AppendEnrollmentGroupRequest\x1a\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\x00\x12w\n\x10\x44\x65leteEnrollment\x12\x32.sensory.api.v1.management.DeleteEnrollmentRequest\x1a-.sensory.api.v1.management.EnrollmentResponse\"\x00\x12\x86\x01\n\x15\x44\x65leteEnrollmentGroup\x12\x37.sensory.api.v1.management.DeleteEnrollmentGroupRequest\x1a\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\x00\x12w\n\x10UpdateEnrollment\x12\x32.sensory.api.v1.management.UpdateEnrollmentRequest\x1a-.sensory.api.v1.management.EnrollmentResponse\"\x00\x12\x86\x01\n\x15UpdateEnrollmentGroup\x12\x37.sensory.api.v1.management.UpdateEnrollmentGroupRequest\x1a\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\x00\x12\x87\x01\n\x1aRemoveEnrollmentsFromGroup\x12\x33.sensory.api.v1.management.RemoveEnrollmentsRequest\x1a\x32.sensory.api.v1.management.EnrollmentGroupResponse\"\x00\x42\x8d\x01\n!ai.sensorycloud.api.v1.managementB%SensoryApiV1ManagementEnrollmentProtoP\x01Z?gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/managementb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,common_dot_common__pb2.DESCRIPTOR,])




_GETENROLLMENTSREQUEST = _descriptor.Descriptor(
  name='GetEnrollmentsRequest',
  full_name='sensory.api.v1.management.GetEnrollmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.management.GetEnrollmentsRequest.userId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=190,
)


_GETENROLLMENTSRESPONSE = _descriptor.Descriptor(
  name='GetEnrollmentsResponse',
  full_name='sensory.api.v1.management.GetEnrollmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enrollments', full_name='sensory.api.v1.management.GetEnrollmentsResponse.enrollments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isRequestorTrusted', full_name='sensory.api.v1.management.GetEnrollmentsResponse.isRequestorTrusted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=312,
)


_ENROLLMENTRESPONSE = _descriptor.Descriptor(
  name='EnrollmentResponse',
  full_name='sensory.api.v1.management.EnrollmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.EnrollmentResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createdAt', full_name='sensory.api.v1.management.EnrollmentResponse.createdAt', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updatedAt', full_name='sensory.api.v1.management.EnrollmentResponse.updatedAt', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.management.EnrollmentResponse.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.management.EnrollmentResponse.modelName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelType', full_name='sensory.api.v1.management.EnrollmentResponse.modelType', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelVersion', full_name='sensory.api.v1.management.EnrollmentResponse.modelVersion', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.management.EnrollmentResponse.deviceId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.management.EnrollmentResponse.userId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='sensory.api.v1.management.EnrollmentResponse.compression', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceName', full_name='sensory.api.v1.management.EnrollmentResponse.deviceName', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='didEnrollWithLiveness', full_name='sensory.api.v1.management.EnrollmentResponse.didEnrollWithLiveness', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenceId', full_name='sensory.api.v1.management.EnrollmentResponse.referenceId', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='didEnrollAsBiometric', full_name='sensory.api.v1.management.EnrollmentResponse.didEnrollAsBiometric', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=756,
)


_GETENROLLMENTGROUPSRESPONSE = _descriptor.Descriptor(
  name='GetEnrollmentGroupsResponse',
  full_name='sensory.api.v1.management.GetEnrollmentGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enrollmentGroups', full_name='sensory.api.v1.management.GetEnrollmentGroupsResponse.enrollmentGroups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=865,
)


_ENROLLMENTGROUPRESPONSE = _descriptor.Descriptor(
  name='EnrollmentGroupResponse',
  full_name='sensory.api.v1.management.EnrollmentGroupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.EnrollmentGroupResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='createdAt', full_name='sensory.api.v1.management.EnrollmentGroupResponse.createdAt', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updatedAt', full_name='sensory.api.v1.management.EnrollmentGroupResponse.updatedAt', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.management.EnrollmentGroupResponse.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.management.EnrollmentGroupResponse.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.management.EnrollmentGroupResponse.modelName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelType', full_name='sensory.api.v1.management.EnrollmentGroupResponse.modelType', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelVersion', full_name='sensory.api.v1.management.EnrollmentGroupResponse.modelVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.management.EnrollmentGroupResponse.userId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollments', full_name='sensory.api.v1.management.EnrollmentGroupResponse.enrollments', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=1209,
)


_CREATEENROLLMENTGROUPREQUEST = _descriptor.Descriptor(
  name='CreateEnrollmentGroupRequest',
  full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.modelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.userId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentIds', full_name='sensory.api.v1.management.CreateEnrollmentGroupRequest.enrollmentIds', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1403,
)


_APPENDENROLLMENTGROUPREQUEST = _descriptor.Descriptor(
  name='AppendEnrollmentGroupRequest',
  full_name='sensory.api.v1.management.AppendEnrollmentGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='sensory.api.v1.management.AppendEnrollmentGroupRequest.groupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentIds', full_name='sensory.api.v1.management.AppendEnrollmentGroupRequest.enrollmentIds', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1486,
)


_DELETEENROLLMENTREQUEST = _descriptor.Descriptor(
  name='DeleteEnrollmentRequest',
  full_name='sensory.api.v1.management.DeleteEnrollmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.DeleteEnrollmentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1535,
)


_DELETEENROLLMENTGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteEnrollmentGroupRequest',
  full_name='sensory.api.v1.management.DeleteEnrollmentGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.DeleteEnrollmentGroupRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1537,
  serialized_end=1590,
)


_UPDATEENROLLMENTREQUEST = _descriptor.Descriptor(
  name='UpdateEnrollmentRequest',
  full_name='sensory.api.v1.management.UpdateEnrollmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.UpdateEnrollmentRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.management.UpdateEnrollmentRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1670,
)


_UPDATEENROLLMENTGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateEnrollmentGroupRequest',
  full_name='sensory.api.v1.management.UpdateEnrollmentGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='sensory.api.v1.management.UpdateEnrollmentGroupRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.management.UpdateEnrollmentGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1750,
)


_REMOVEENROLLMENTSREQUEST = _descriptor.Descriptor(
  name='RemoveEnrollmentsRequest',
  full_name='sensory.api.v1.management.RemoveEnrollmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='sensory.api.v1.management.RemoveEnrollmentsRequest.groupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentIds', full_name='sensory.api.v1.management.RemoveEnrollmentsRequest.enrollmentIds', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1839,
)

_GETENROLLMENTSRESPONSE.fields_by_name['enrollments'].message_type = _ENROLLMENTRESPONSE
_ENROLLMENTRESPONSE.fields_by_name['createdAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENROLLMENTRESPONSE.fields_by_name['updatedAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENROLLMENTRESPONSE.fields_by_name['modelType'].enum_type = common_dot_common__pb2._MODELTYPE
_ENROLLMENTRESPONSE.fields_by_name['compression'].message_type = common_dot_common__pb2._COMPRESSIONCONFIGURATION
_GETENROLLMENTGROUPSRESPONSE.fields_by_name['enrollmentGroups'].message_type = _ENROLLMENTGROUPRESPONSE
_ENROLLMENTGROUPRESPONSE.fields_by_name['createdAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENROLLMENTGROUPRESPONSE.fields_by_name['updatedAt'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENROLLMENTGROUPRESPONSE.fields_by_name['modelType'].enum_type = common_dot_common__pb2._MODELTYPE
_ENROLLMENTGROUPRESPONSE.fields_by_name['enrollments'].message_type = _ENROLLMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetEnrollmentsRequest'] = _GETENROLLMENTSREQUEST
DESCRIPTOR.message_types_by_name['GetEnrollmentsResponse'] = _GETENROLLMENTSRESPONSE
DESCRIPTOR.message_types_by_name['EnrollmentResponse'] = _ENROLLMENTRESPONSE
DESCRIPTOR.message_types_by_name['GetEnrollmentGroupsResponse'] = _GETENROLLMENTGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['EnrollmentGroupResponse'] = _ENROLLMENTGROUPRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentGroupRequest'] = _CREATEENROLLMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['AppendEnrollmentGroupRequest'] = _APPENDENROLLMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteEnrollmentRequest'] = _DELETEENROLLMENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteEnrollmentGroupRequest'] = _DELETEENROLLMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateEnrollmentRequest'] = _UPDATEENROLLMENTREQUEST
DESCRIPTOR.message_types_by_name['UpdateEnrollmentGroupRequest'] = _UPDATEENROLLMENTGROUPREQUEST
DESCRIPTOR.message_types_by_name['RemoveEnrollmentsRequest'] = _REMOVEENROLLMENTSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetEnrollmentsRequest = _reflection.GeneratedProtocolMessageType('GetEnrollmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENROLLMENTSREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.GetEnrollmentsRequest)
  })
_sym_db.RegisterMessage(GetEnrollmentsRequest)

GetEnrollmentsResponse = _reflection.GeneratedProtocolMessageType('GetEnrollmentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENROLLMENTSRESPONSE,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.GetEnrollmentsResponse)
  })
_sym_db.RegisterMessage(GetEnrollmentsResponse)

EnrollmentResponse = _reflection.GeneratedProtocolMessageType('EnrollmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENROLLMENTRESPONSE,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.EnrollmentResponse)
  })
_sym_db.RegisterMessage(EnrollmentResponse)

GetEnrollmentGroupsResponse = _reflection.GeneratedProtocolMessageType('GetEnrollmentGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENROLLMENTGROUPSRESPONSE,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.GetEnrollmentGroupsResponse)
  })
_sym_db.RegisterMessage(GetEnrollmentGroupsResponse)

EnrollmentGroupResponse = _reflection.GeneratedProtocolMessageType('EnrollmentGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENROLLMENTGROUPRESPONSE,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.EnrollmentGroupResponse)
  })
_sym_db.RegisterMessage(EnrollmentGroupResponse)

CreateEnrollmentGroupRequest = _reflection.GeneratedProtocolMessageType('CreateEnrollmentGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTGROUPREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.CreateEnrollmentGroupRequest)
  })
_sym_db.RegisterMessage(CreateEnrollmentGroupRequest)

AppendEnrollmentGroupRequest = _reflection.GeneratedProtocolMessageType('AppendEnrollmentGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPENDENROLLMENTGROUPREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.AppendEnrollmentGroupRequest)
  })
_sym_db.RegisterMessage(AppendEnrollmentGroupRequest)

DeleteEnrollmentRequest = _reflection.GeneratedProtocolMessageType('DeleteEnrollmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENROLLMENTREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.DeleteEnrollmentRequest)
  })
_sym_db.RegisterMessage(DeleteEnrollmentRequest)

DeleteEnrollmentGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteEnrollmentGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENROLLMENTGROUPREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.DeleteEnrollmentGroupRequest)
  })
_sym_db.RegisterMessage(DeleteEnrollmentGroupRequest)

UpdateEnrollmentRequest = _reflection.GeneratedProtocolMessageType('UpdateEnrollmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENROLLMENTREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.UpdateEnrollmentRequest)
  })
_sym_db.RegisterMessage(UpdateEnrollmentRequest)

UpdateEnrollmentGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateEnrollmentGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENROLLMENTGROUPREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.UpdateEnrollmentGroupRequest)
  })
_sym_db.RegisterMessage(UpdateEnrollmentGroupRequest)

RemoveEnrollmentsRequest = _reflection.GeneratedProtocolMessageType('RemoveEnrollmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEENROLLMENTSREQUEST,
  '__module__' : 'v1.management.enrollment_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.management.RemoveEnrollmentsRequest)
  })
_sym_db.RegisterMessage(RemoveEnrollmentsRequest)


DESCRIPTOR._options = None
_GETENROLLMENTSREQUEST.fields_by_name['userId']._options = None
_CREATEENROLLMENTGROUPREQUEST.fields_by_name['id']._options = None
_CREATEENROLLMENTGROUPREQUEST.fields_by_name['name']._options = None
_CREATEENROLLMENTGROUPREQUEST.fields_by_name['description']._options = None
_CREATEENROLLMENTGROUPREQUEST.fields_by_name['modelName']._options = None
_CREATEENROLLMENTGROUPREQUEST.fields_by_name['userId']._options = None
_APPENDENROLLMENTGROUPREQUEST.fields_by_name['groupId']._options = None
_DELETEENROLLMENTREQUEST.fields_by_name['id']._options = None
_DELETEENROLLMENTGROUPREQUEST.fields_by_name['id']._options = None
_UPDATEENROLLMENTREQUEST.fields_by_name['id']._options = None
_UPDATEENROLLMENTREQUEST.fields_by_name['description']._options = None
_UPDATEENROLLMENTGROUPREQUEST.fields_by_name['id']._options = None
_UPDATEENROLLMENTGROUPREQUEST.fields_by_name['name']._options = None
_REMOVEENROLLMENTSREQUEST.fields_by_name['groupId']._options = None
_REMOVEENROLLMENTSREQUEST.fields_by_name['enrollmentIds']._options = None

_ENROLLMENTSERVICE = _descriptor.ServiceDescriptor(
  name='EnrollmentService',
  full_name='sensory.api.v1.management.EnrollmentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1842,
  serialized_end=3042,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEnrollments',
    full_name='sensory.api.v1.management.EnrollmentService.GetEnrollments',
    index=0,
    containing_service=None,
    input_type=_GETENROLLMENTSREQUEST,
    output_type=_GETENROLLMENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEnrollmentGroups',
    full_name='sensory.api.v1.management.EnrollmentService.GetEnrollmentGroups',
    index=1,
    containing_service=None,
    input_type=_GETENROLLMENTSREQUEST,
    output_type=_GETENROLLMENTGROUPSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEnrollmentGroup',
    full_name='sensory.api.v1.management.EnrollmentService.CreateEnrollmentGroup',
    index=2,
    containing_service=None,
    input_type=_CREATEENROLLMENTGROUPREQUEST,
    output_type=_ENROLLMENTGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AppendEnrollmentGroup',
    full_name='sensory.api.v1.management.EnrollmentService.AppendEnrollmentGroup',
    index=3,
    containing_service=None,
    input_type=_APPENDENROLLMENTGROUPREQUEST,
    output_type=_ENROLLMENTGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEnrollment',
    full_name='sensory.api.v1.management.EnrollmentService.DeleteEnrollment',
    index=4,
    containing_service=None,
    input_type=_DELETEENROLLMENTREQUEST,
    output_type=_ENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEnrollmentGroup',
    full_name='sensory.api.v1.management.EnrollmentService.DeleteEnrollmentGroup',
    index=5,
    containing_service=None,
    input_type=_DELETEENROLLMENTGROUPREQUEST,
    output_type=_ENROLLMENTGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEnrollment',
    full_name='sensory.api.v1.management.EnrollmentService.UpdateEnrollment',
    index=6,
    containing_service=None,
    input_type=_UPDATEENROLLMENTREQUEST,
    output_type=_ENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEnrollmentGroup',
    full_name='sensory.api.v1.management.EnrollmentService.UpdateEnrollmentGroup',
    index=7,
    containing_service=None,
    input_type=_UPDATEENROLLMENTGROUPREQUEST,
    output_type=_ENROLLMENTGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveEnrollmentsFromGroup',
    full_name='sensory.api.v1.management.EnrollmentService.RemoveEnrollmentsFromGroup',
    index=8,
    containing_service=None,
    input_type=_REMOVEENROLLMENTSREQUEST,
    output_type=_ENROLLMENTGROUPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENROLLMENTSERVICE)

DESCRIPTOR.services_by_name['EnrollmentService'] = _ENROLLMENTSERVICE

# @@protoc_insertion_point(module_scope)
